@@ -8,9 +8,8 @@ import csv
 import io
 from typing import Any
 
-from langchain.tools import BaseTool
-
 from codeinterpreterapi import CodeInterpreterSession
+from langchain_core.tools import BaseTool
 
 
 class ExampleKnowledgeBaseTool(BaseTool):
