@@ -1,5 +1,12 @@
+from . import _patch_parser  # noqa
+
 from codeinterpreterapi.config import settings
 from codeinterpreterapi.schema import File
 from codeinterpreterapi.session import CodeInterpreterSession
 
-__all__ = ["CodeInterpreterSession", "File", "settings"]
+
+__all__ = [
+    "CodeInterpreterSession",
+    "File",
+    "settings",
+]
